cli

package
v1.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: MIT Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version = func() string {
	if info, ok := debug.ReadBuildInfo(); ok && info.Main.Version != "" && info.Main.Version != "(devel)" {
		return info.Main.Version
	}
	return "dev"
}()

Version is set at build time via ldflags. Falls back to Go module version from build info (works with go install).

Functions

func Execute

func Execute()

Execute is the main entry point for the CLI.

Types

This section is empty.

Jump to